import { world, system, BlockPermutation } from "@minecraft/server";

world.beforeEvents.explosion.subscribe(data => {
  const { dimension, source } = data;
  if (source && source.typeId == "minecraft:creeper") {
    const location = source.location;
    const isCharged = source.hasComponent("minecraft:is_charged");
    system.run(() => {
      const radius = isCharged ? 7 : 4;
      for (let x = -radius; x <= radius; x++) {
        for (let y = -radius; y <= radius; y++) {
          for (let z = -radius; z <= radius; z++) {
            if (Math.pow(x, 2) + Math.pow(y, 2) + Math.pow(z, 2) <= Math.pow(radius, 2)) {
              const block = dimension.getBlock({ x: location.x + x, y: location.y + y, z: location.z + z });
              if (block.isAir && block.below().isSolid && Math.random() < 0.1) {
                block.setPermutation(BlockPermutation.resolve("cd:creeper_spores", { "cd:rotation": Math.floor(Math.random() * 4), "cd:stage": 0, "cd:is_charged": isCharged ? Math.random() < 0.05 : false }));
              };
            };
          };
        };
      };
    });
  };
});

world.afterEvents.playerBreakBlock.subscribe(data => {
  const { block, dimension } = data;
  if (block.above().typeId == "cd:creeper_spores") {
    dimension.runCommand(`setblock ${block.above().x} ${block.above().y} ${block.above().z} air destroy`);
  };
});